@@ -1,14 +1,15 @@
-from django_filters import (FilterSet, CharFilter,)
 from django.forms.widgets import TextInput
-from elo import logger
+from django_filters import (FilterSet, CharFilter, )
+
 from elo.models import Word
 
 
 class WordFilter(FilterSet):
-
-    source_text__icontains = CharFilter(label="", field_name="source_text",
-                             widget=TextInput(attrs={'placeholder': 'Search source text'}),
-                             lookup_expr='icontains')
+    source_text__icontains = CharFilter(
+        label="", field_name="source_text",
+        widget=TextInput(attrs={'placeholder': 'Search source text'}),
+        lookup_expr='icontains'
+    )
 
     def __init__(self, data=None, *args, **kwargs):
         # this is to force the initial values of the filter to dutch, english, nederlands
