@@ -19,16 +19,16 @@ class Language(models.Model):
 
 
 class Dialect(models.Model):
-    language = models.ForeignKey(Language,
-                                 on_delete=models.CASCADE)  # Field name made lowercase. This field type is a guess.
-    name = models.TextField(db_column='NAME', blank=True,
-                            null=True)  # Field name made lowercase. This field type is a guess.
-    adddate = models.DateTimeField(db_column='ADDDATE', blank=True,
-                                   null=True)  # Field name made lowercase.
-    mtdate = models.DateTimeField(db_column='MTDATE', blank=True,
-                                  null=True)  # Field name made lowercase.
-    mtanr = models.TextField(db_column='MTANR', blank=True,
-                             null=True)  # Field name made lowercase. This field type is a guess.
+    # Field name made lowercase. This field type is a guess.
+    language = models.ForeignKey(Language, on_delete=models.CASCADE)
+    # Field name made lowercase. This field type is a guess.
+    name = models.TextField(db_column='NAME', blank=True, null=True)
+    # Field name made lowercase.
+    adddate = models.DateTimeField(db_column='ADDDATE', blank=True, null=True)
+    # Field name made lowercase.
+    mtdate = models.DateTimeField(db_column='MTDATE', blank=True, null=True)
+    # Field name made lowercase. This field type is a guess.
+    mtanr = models.TextField(db_column='MTANR', blank=True, null=True)
 
     class Meta:
         managed = True
@@ -39,16 +39,16 @@ class Dialect(models.Model):
 
 
 class Domain(models.Model):
-    language = models.ForeignKey(Language,
-                                 on_delete=models.CASCADE)  # Field name made lowercase. This field type is a guess.
-    name = models.TextField(db_column='NAME', blank=True,
-                            null=True)  # Field name made lowercase. This field type is a guess.
-    mtdate = models.DateTimeField(db_column='MTDATE', blank=True,
-                                  null=True)  # Field name made lowercase.
-    mtanr = models.TextField(db_column='MTANR', blank=True,
-                             null=True)  # Field name made lowercase. This field type is a guess.
-    adddate = models.DateTimeField(db_column='ADDDATE', blank=True,
-                                   null=True)  # Field name made lowercase.
+    # Field name made lowercase. This field type is a guess.
+    language = models.ForeignKey(Language, on_delete=models.CASCADE)
+    # Field name made lowercase. This field type is a guess.
+    name = models.TextField(db_column='NAME', blank=True, null=True)
+    # Field name made lowercase.
+    mtdate = models.DateTimeField(db_column='MTDATE', blank=True, null=True)
+    # Field name made lowercase. This field type is a guess.
+    mtanr = models.TextField(db_column='MTANR', blank=True, null=True)
+    # Field name made lowercase.
+    adddate = models.DateTimeField(db_column='ADDDATE', blank=True, null=True)
 
     class Meta:
         managed = True
@@ -116,12 +116,14 @@ class EloquentUser(django.contrib.auth.models.User):
 class Word(models.Model):
     source_text = models.CharField(max_length=256)
     source_language = models.ForeignKey(
-        Language, verbose_name="Source language", related_name="source_language", on_delete=models.CASCADE)
+        Language, verbose_name="Source language", related_name="source_language",
+        on_delete=models.CASCADE)
     dialect = models.ForeignKey(Dialect, verbose_name="Pronunciation", on_delete=models.CASCADE)
     domain = models.ForeignKey(Domain, on_delete=models.CASCADE, default=1)
     translated_text = models.CharField(max_length=256)
     target_language = models.ForeignKey(
-        Language, verbose_name="Translated language", related_name="target_language", on_delete=models.CASCADE)
+        Language, verbose_name="Translated language", related_name="target_language",
+        on_delete=models.CASCADE)
     mp3_number = models.IntegerField()
     mp3 = models.FileField(upload_to='mp3', blank=True, null=True)
     adddate = models.DateTimeField(auto_now_add=True)
@@ -204,4 +206,3 @@ class WordDialect(models.Model):
 
     def __str__(self):
         return f"{self.word}-{self.dialect}"
-
